MethodChannelNoScreenshot class

An implementation of NoScreenshotPlatform that uses method channels.

Inheritance

Constructors

MethodChannelNoScreenshot()

Properties

eventChannel EventChannel
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshotStream Stream<ScreenshotSnapshot>
Stream to screenshot activities ScreenshotSnapshot This stream will emit a ScreenshotSnapshot whenever a screenshot is taken. The ScreenshotSnapshot contains the path to the screenshot file. throw UnmimplementedError if not implement
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
screenshotOff() Future<bool>
Return true if screenshot capabilities has been successfully disabled or is currently disabled and false otherwise. throw UnmimplementedError if not implement
override
screenshotOn() Future<bool>
Return true if screenshot capabilities has been successfully enabled or is currently enabled and false otherwise. throw UnmimplementedError if not implement
override
screenshotWithBlur({double blurRadius = 30.0}) Future<bool>
Always enables blur overlay mode (idempotent — safe to call repeatedly).
override
screenshotWithColor({int color = 0xFF000000}) Future<bool>
Always enables color overlay mode (idempotent — safe to call repeatedly).
override
screenshotWithImage() Future<bool>
Always enables image overlay mode (idempotent — safe to call repeatedly).
override
startScreenRecordingListening() Future<void>
Start listening to screen recording activities
override
startScreenshotListening() Future<void>
override
stopScreenRecordingListening() Future<void>
Stop listening to screen recording activities
override
stopScreenshotListening() Future<void>
Stop listening to screenshot activities
override
toggleScreenshot() Future<bool>
Return true if screenshot capabilities has been successfully toggle from it previous state and false if the attempt to toggle failed. throw UnmimplementedError if not implement
override
toggleScreenshotWithBlur({double blurRadius = 30.0}) Future<bool>
override
toggleScreenshotWithColor({int color = 0xFF000000}) Future<bool>
override
toggleScreenshotWithImage() Future<bool>
Return true if screenshot capabilities has been successfully enabled or is currently enabled and false otherwise. throw UnmimplementedError if not implement
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited