toggleScreenshot method

Future<bool> toggleScreenshot()

Return true if screenshot capabilities has been successfully toggle from it previous state and false if the attempt to toggle failed. throw UnmimplementedError if not implement

Always returns false when an iOS build runs on a Mac ("Designed for iPhone/iPad" on Apple silicon) — screenshot prevention is not supported there; see screenshotOff.

Implementation

Future<bool> toggleScreenshot() {
  throw UnimplementedError('toggleScreenshot() has not been implemented.');
}