SecureRouteConfig class

Configuration for a single route's protection policy.

Constructors

SecureRouteConfig({OverlayMode mode = OverlayMode.secure, double blurRadius = 30.0, int color = 0xFF000000})
const

Properties

blurRadius → double
final
color → int
final
hashCode → int
The hash code for this object.
no setteroverride
mode → OverlayMode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override