ScreenshotSnapshot class
Constructors
- ScreenshotSnapshot({required String screenshotPath, required bool isScreenshotProtectionOn, required bool wasScreenshotTaken, bool isScreenRecording = false, int timestamp = 0, String sourceApp = ''})
-
ScreenshotSnapshot.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isScreenRecording → bool
-
final
- isScreenshotProtectionOn → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenshotPath → String
-
File path of the captured screenshot.
final
- sourceApp → String
-
Human-readable name of the application that triggered the event.
final
- timestamp → int
-
Milliseconds since epoch when the event was detected.
final
- wasScreenshotTaken → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override